@@ -1,4 +1,3 @@
-# coding: utf-8
 """Test installation of notebook extensions"""
 
 # Copyright (c) Jupyter Development Team.
@@ -6,6 +5,7 @@
 
 import glob
 import os
+import pytest
 import sys
 import tarfile
 import zipfile
@@ -321,7 +321,7 @@ class TestInstallNBExtension(TestCase):
         assert check_nbextension([f], user=True)
         assert not check_nbextension([f, pjoin('dne', f)], user=True)
     
-    @dec.skip_win32
+    @pytest.mark.skipif(sys.platform == "win32", reason="do not run on windows")
     def test_install_symlink(self):
         with TemporaryDirectory() as d:
             f = u'ƒ.js'
@@ -333,7 +333,7 @@ class TestInstallNBExtension(TestCase):
         link = os.readlink(dest)
         self.assertEqual(link, src)
     
-    @dec.skip_win32
+    @pytest.mark.skipif(sys.platform == "win32", reason="do not run on windows")
     def test_overwrite_broken_symlink(self):
         with TemporaryDirectory() as d:
             f = u'ƒ.js'
@@ -349,7 +349,7 @@ class TestInstallNBExtension(TestCase):
         link = os.readlink(dest)
         self.assertEqual(link, src2)
 
-    @dec.skip_win32
+    @pytest.mark.skipif(sys.platform == "win32", reason="do not run on windows")
     def test_install_symlink_destination(self):
         with TemporaryDirectory() as d:
             f = u'ƒ.js'
@@ -362,7 +362,7 @@ class TestInstallNBExtension(TestCase):
         link = os.readlink(dest)
         self.assertEqual(link, src)
 
-    @dec.skip_win32
+    @pytest.mark.skipif(sys.platform == "win32", reason="do not run on windows")
     def test_install_symlink_bad(self):
         with self.assertRaises(ValueError):
             install_nbextension("http://example.com/foo.js", symlink=True)
